##  Getting Started
  1. Activate the AI agent extension to the meta model. Extend your meta model with the necessary attributes and fact sheet subtypes. For more information, see [AI Agent Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/ai-agent-extension-to-meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Activate an optional meta model extension to model and govern your organization’s AI agents and MCP servers.").
  2. Discover AI agents. Configure integrations to discover your AI agents. Use the AI agent discovery inbox to review the discovered items and add relevant ones to your workspace. For more information, see [AI Agent Discovery](https://help.sap.com/docs/leanix/ea/ai-agent-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "Discover AI agents and MCP servers by setting up integrations with agent-building platforms and registry systems. Review discovered items in the AI agent discovery inbox and add relevant ones to your inventory.").
  3. Manage AI agents. Monitor key metrics for your AI agents on the AI agent hub dashboard. Visualize your AI agent landscape in dedicated reports, contextualized within applications, business capabilities, and other architectural elements.


YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
